==> ipmi-0.1.tar.gz: ipmi/python/ipmichassis.py <==
#
# Copyright (c) 2002 Doug White
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# 
#
# ipmichassis.py: Chassis commands
#

import struct

# chassis_control: Set chassis power/reset level
def control(sess, s):
    # valid states:
    # 'off'
    # 'on'
    # 'cycle'
    # 'reset'
    # 'nmi'

    targ = s.lower()
    states = ['off', 'on', 'cycle', 'reset', 'nmi']
    
    if targ not in states:
        raise ValueError, "Not a supported state"

    try:
        cmd = states.index(targ)
    except:
        raise

    # execute
    ret = sess.send(0x20, 0x0, 0x81, 0x0, 0, 0x0, 0x2, struct.pack('<B', cmd))
    if ord(ret[0]) != 0x0:
        raise ValueError, "reset wasn't successful (%d)" % ord(ret[0])

==> ipmi-0.2.tar.gz: ipmi/python/ipmichassis.py <==
#
# Copyright (c) 2002 Doug White
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $Id: ipmichassis.py,v 1.3 2002/07/19 03:30:40 dwhite Exp $
#
# ipmichassis.py: Chassis commands
#

import struct
import ipmimessage

# chassis_control: Set chassis power/reset level
def control(sess, s):
    # valid states:
    # 'off'
    # 'on'
    # 'cycle'
    # 'reset'
    # 'nmi'

    targ = s.lower()
    states = ['off', 'on', 'cycle', 'reset', 'nmi']
    
    if targ not in states:
        raise ValueError, "Not a supported state"

    try:
        cmd = states.index(targ)
    except:
        raise

    # execute
    # ret = sess.send(0x20, 0x0, 0x81, 0x0, 0, 0x0, 0x2, struct.pack('<B', cmd))
    m = ipmimessage.IPMIMessage()
    m.quickload(0x20, 0x0, 0x81, 0x0, 0, 0x0, 0x2, struct.pack('<B', cmd))
    rm = sess.sendmessage(m)
    ret = rm.data
    if ord(ret[0]) != 0x0:
        raise ValueError, "reset wasn't successful (%d)" % ord(ret[0])
